# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ProfileOneConnectArgs', 'ProfileOneConnect']

@pulumi.input_type
class ProfileOneConnectArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 idle_timeout_override: Optional[pulumi.Input[str]] = None,
                 limit_type: Optional[pulumi.Input[str]] = None,
                 max_age: Optional[pulumi.Input[int]] = None,
                 max_reuse: Optional[pulumi.Input[int]] = None,
                 max_size: Optional[pulumi.Input[int]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 share_pools: Optional[pulumi.Input[str]] = None,
                 source_mask: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProfileOneConnect resource.
        :param pulumi.Input[str] name: Name of Profile should be full path.The full path is the combination of the `partition + profile_name`,For example `/Common/test-oneconnect-profile`.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] idle_timeout_override: Specifies the number of seconds that a connection is idle before the connection flow is eligible for deletion. Possible values are `disabled`, `indefinite`, or a numeric value that you specify. The default value is `disabled`
        :param pulumi.Input[str] limit_type: Controls how connection limits are enforced in conjunction with OneConnect. The default is `None`. Supported Values: `[None,idle,strict]`
        :param pulumi.Input[int] max_age: Specifies the maximum age in number of seconds allowed for a connection in the connection reuse pool. For any connection with an age higher than this value, the system removes that connection from the reuse pool. The default value is `86400`.
        :param pulumi.Input[int] max_reuse: Specifies the maximum number of times that a server-side connection can be reused. The default value is `1000`.
        :param pulumi.Input[int] max_size: Specifies the maximum number of connections that the system holds in the connection reuse pool. If the pool is already full, then the server-side connection closes after the response is completed. The default value is `10000`.
        :param pulumi.Input[str] partition: Displays the administrative partition within which this profile resides
        :param pulumi.Input[str] share_pools: Specify if you want to share the pool, default value is `disabled`.
        :param pulumi.Input[str] source_mask: Specifies a source IP mask. The default value is `0.0.0.0`. The system applies the value of this option to the source address to determine its eligibility for reuse. A mask of 0.0.0.0 causes the system to share reused connections across all clients. A host mask (all 1's in binary), causes the system to share only those reused connections originating from the same client IP address.
        """
        pulumi.set(__self__, "name", name)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if idle_timeout_override is not None:
            pulumi.set(__self__, "idle_timeout_override", idle_timeout_override)
        if limit_type is not None:
            pulumi.set(__self__, "limit_type", limit_type)
        if max_age is not None:
            pulumi.set(__self__, "max_age", max_age)
        if max_reuse is not None:
            pulumi.set(__self__, "max_reuse", max_reuse)
        if max_size is not None:
            pulumi.set(__self__, "max_size", max_size)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if share_pools is not None:
            pulumi.set(__self__, "share_pools", share_pools)
        if source_mask is not None:
            pulumi.set(__self__, "source_mask", source_mask)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of Profile should be full path.The full path is the combination of the `partition + profile_name`,For example `/Common/test-oneconnect-profile`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter(name="idleTimeoutOverride")
    def idle_timeout_override(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the number of seconds that a connection is idle before the connection flow is eligible for deletion. Possible values are `disabled`, `indefinite`, or a numeric value that you specify. The default value is `disabled`
        """
        return pulumi.get(self, "idle_timeout_override")

    @idle_timeout_override.setter
    def idle_timeout_override(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "idle_timeout_override", value)

    @property
    @pulumi.getter(name="limitType")
    def limit_type(self) -> Optional[pulumi.Input[str]]:
        """
        Controls how connection limits are enforced in conjunction with OneConnect. The default is `None`. Supported Values: `[None,idle,strict]`
        """
        return pulumi.get(self, "limit_type")

    @limit_type.setter
    def limit_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "limit_type", value)

    @property
    @pulumi.getter(name="maxAge")
    def max_age(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum age in number of seconds allowed for a connection in the connection reuse pool. For any connection with an age higher than this value, the system removes that connection from the reuse pool. The default value is `86400`.
        """
        return pulumi.get(self, "max_age")

    @max_age.setter
    def max_age(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_age", value)

    @property
    @pulumi.getter(name="maxReuse")
    def max_reuse(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of times that a server-side connection can be reused. The default value is `1000`.
        """
        return pulumi.get(self, "max_reuse")

    @max_reuse.setter
    def max_reuse(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_reuse", value)

    @property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of connections that the system holds in the connection reuse pool. If the pool is already full, then the server-side connection closes after the response is completed. The default value is `10000`.
        """
        return pulumi.get(self, "max_size")

    @max_size.setter
    def max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_size", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        Displays the administrative partition within which this profile resides
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter(name="sharePools")
    def share_pools(self) -> Optional[pulumi.Input[str]]:
        """
        Specify if you want to share the pool, default value is `disabled`.
        """
        return pulumi.get(self, "share_pools")

    @share_pools.setter
    def share_pools(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "share_pools", value)

    @property
    @pulumi.getter(name="sourceMask")
    def source_mask(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies a source IP mask. The default value is `0.0.0.0`. The system applies the value of this option to the source address to determine its eligibility for reuse. A mask of 0.0.0.0 causes the system to share reused connections across all clients. A host mask (all 1's in binary), causes the system to share only those reused connections originating from the same client IP address.
        """
        return pulumi.get(self, "source_mask")

    @source_mask.setter
    def source_mask(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_mask", value)


@pulumi.input_type
class _ProfileOneConnectState:
    def __init__(__self__, *,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 idle_timeout_override: Optional[pulumi.Input[str]] = None,
                 limit_type: Optional[pulumi.Input[str]] = None,
                 max_age: Optional[pulumi.Input[int]] = None,
                 max_reuse: Optional[pulumi.Input[int]] = None,
                 max_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 share_pools: Optional[pulumi.Input[str]] = None,
                 source_mask: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProfileOneConnect resources.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] idle_timeout_override: Specifies the number of seconds that a connection is idle before the connection flow is eligible for deletion. Possible values are `disabled`, `indefinite`, or a numeric value that you specify. The default value is `disabled`
        :param pulumi.Input[str] limit_type: Controls how connection limits are enforced in conjunction with OneConnect. The default is `None`. Supported Values: `[None,idle,strict]`
        :param pulumi.Input[int] max_age: Specifies the maximum age in number of seconds allowed for a connection in the connection reuse pool. For any connection with an age higher than this value, the system removes that connection from the reuse pool. The default value is `86400`.
        :param pulumi.Input[int] max_reuse: Specifies the maximum number of times that a server-side connection can be reused. The default value is `1000`.
        :param pulumi.Input[int] max_size: Specifies the maximum number of connections that the system holds in the connection reuse pool. If the pool is already full, then the server-side connection closes after the response is completed. The default value is `10000`.
        :param pulumi.Input[str] name: Name of Profile should be full path.The full path is the combination of the `partition + profile_name`,For example `/Common/test-oneconnect-profile`.
        :param pulumi.Input[str] partition: Displays the administrative partition within which this profile resides
        :param pulumi.Input[str] share_pools: Specify if you want to share the pool, default value is `disabled`.
        :param pulumi.Input[str] source_mask: Specifies a source IP mask. The default value is `0.0.0.0`. The system applies the value of this option to the source address to determine its eligibility for reuse. A mask of 0.0.0.0 causes the system to share reused connections across all clients. A host mask (all 1's in binary), causes the system to share only those reused connections originating from the same client IP address.
        """
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if idle_timeout_override is not None:
            pulumi.set(__self__, "idle_timeout_override", idle_timeout_override)
        if limit_type is not None:
            pulumi.set(__self__, "limit_type", limit_type)
        if max_age is not None:
            pulumi.set(__self__, "max_age", max_age)
        if max_reuse is not None:
            pulumi.set(__self__, "max_reuse", max_reuse)
        if max_size is not None:
            pulumi.set(__self__, "max_size", max_size)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if share_pools is not None:
            pulumi.set(__self__, "share_pools", share_pools)
        if source_mask is not None:
            pulumi.set(__self__, "source_mask", source_mask)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter(name="idleTimeoutOverride")
    def idle_timeout_override(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the number of seconds that a connection is idle before the connection flow is eligible for deletion. Possible values are `disabled`, `indefinite`, or a numeric value that you specify. The default value is `disabled`
        """
        return pulumi.get(self, "idle_timeout_override")

    @idle_timeout_override.setter
    def idle_timeout_override(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "idle_timeout_override", value)

    @property
    @pulumi.getter(name="limitType")
    def limit_type(self) -> Optional[pulumi.Input[str]]:
        """
        Controls how connection limits are enforced in conjunction with OneConnect. The default is `None`. Supported Values: `[None,idle,strict]`
        """
        return pulumi.get(self, "limit_type")

    @limit_type.setter
    def limit_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "limit_type", value)

    @property
    @pulumi.getter(name="maxAge")
    def max_age(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum age in number of seconds allowed for a connection in the connection reuse pool. For any connection with an age higher than this value, the system removes that connection from the reuse pool. The default value is `86400`.
        """
        return pulumi.get(self, "max_age")

    @max_age.setter
    def max_age(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_age", value)

    @property
    @pulumi.getter(name="maxReuse")
    def max_reuse(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of times that a server-side connection can be reused. The default value is `1000`.
        """
        return pulumi.get(self, "max_reuse")

    @max_reuse.setter
    def max_reuse(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_reuse", value)

    @property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of connections that the system holds in the connection reuse pool. If the pool is already full, then the server-side connection closes after the response is completed. The default value is `10000`.
        """
        return pulumi.get(self, "max_size")

    @max_size.setter
    def max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_size", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Profile should be full path.The full path is the combination of the `partition + profile_name`,For example `/Common/test-oneconnect-profile`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        Displays the administrative partition within which this profile resides
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter(name="sharePools")
    def share_pools(self) -> Optional[pulumi.Input[str]]:
        """
        Specify if you want to share the pool, default value is `disabled`.
        """
        return pulumi.get(self, "share_pools")

    @share_pools.setter
    def share_pools(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "share_pools", value)

    @property
    @pulumi.getter(name="sourceMask")
    def source_mask(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies a source IP mask. The default value is `0.0.0.0`. The system applies the value of this option to the source address to determine its eligibility for reuse. A mask of 0.0.0.0 causes the system to share reused connections across all clients. A host mask (all 1's in binary), causes the system to share only those reused connections originating from the same client IP address.
        """
        return pulumi.get(self, "source_mask")

    @source_mask.setter
    def source_mask(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_mask", value)


class ProfileOneConnect(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 idle_timeout_override: Optional[pulumi.Input[str]] = None,
                 limit_type: Optional[pulumi.Input[str]] = None,
                 max_age: Optional[pulumi.Input[int]] = None,
                 max_reuse: Optional[pulumi.Input[int]] = None,
                 max_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 share_pools: Optional[pulumi.Input[str]] = None,
                 source_mask: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `ltm.ProfileOneConnect` Configures a custom profile_oneconnect for use by health checks.

        Resources should be named with their "full path". The full path is the combination of the partition + name (example: /Common/my-pool ) or  partition + directory + name of the resource  (example: /Common/test/my-pool )

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_oneconnect = f5bigip.ltm.ProfileOneConnect("test-oneconnect", name="/Common/test-oneconnect")
        ```

        ## Import

        BIG-IP LTM oneconnect profiles can be imported using the `name` , e.g.

        ```sh
         $ pulumi import f5bigip:ltm/profileOneConnect:ProfileOneConnect test-oneconnect /Common/test-oneconnect
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] idle_timeout_override: Specifies the number of seconds that a connection is idle before the connection flow is eligible for deletion. Possible values are `disabled`, `indefinite`, or a numeric value that you specify. The default value is `disabled`
        :param pulumi.Input[str] limit_type: Controls how connection limits are enforced in conjunction with OneConnect. The default is `None`. Supported Values: `[None,idle,strict]`
        :param pulumi.Input[int] max_age: Specifies the maximum age in number of seconds allowed for a connection in the connection reuse pool. For any connection with an age higher than this value, the system removes that connection from the reuse pool. The default value is `86400`.
        :param pulumi.Input[int] max_reuse: Specifies the maximum number of times that a server-side connection can be reused. The default value is `1000`.
        :param pulumi.Input[int] max_size: Specifies the maximum number of connections that the system holds in the connection reuse pool. If the pool is already full, then the server-side connection closes after the response is completed. The default value is `10000`.
        :param pulumi.Input[str] name: Name of Profile should be full path.The full path is the combination of the `partition + profile_name`,For example `/Common/test-oneconnect-profile`.
        :param pulumi.Input[str] partition: Displays the administrative partition within which this profile resides
        :param pulumi.Input[str] share_pools: Specify if you want to share the pool, default value is `disabled`.
        :param pulumi.Input[str] source_mask: Specifies a source IP mask. The default value is `0.0.0.0`. The system applies the value of this option to the source address to determine its eligibility for reuse. A mask of 0.0.0.0 causes the system to share reused connections across all clients. A host mask (all 1's in binary), causes the system to share only those reused connections originating from the same client IP address.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileOneConnectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.ProfileOneConnect` Configures a custom profile_oneconnect for use by health checks.

        Resources should be named with their "full path". The full path is the combination of the partition + name (example: /Common/my-pool ) or  partition + directory + name of the resource  (example: /Common/test/my-pool )

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_oneconnect = f5bigip.ltm.ProfileOneConnect("test-oneconnect", name="/Common/test-oneconnect")
        ```

        ## Import

        BIG-IP LTM oneconnect profiles can be imported using the `name` , e.g.

        ```sh
         $ pulumi import f5bigip:ltm/profileOneConnect:ProfileOneConnect test-oneconnect /Common/test-oneconnect
        ```

        :param str resource_name: The name of the resource.
        :param ProfileOneConnectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileOneConnectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 idle_timeout_override: Optional[pulumi.Input[str]] = None,
                 limit_type: Optional[pulumi.Input[str]] = None,
                 max_age: Optional[pulumi.Input[int]] = None,
                 max_reuse: Optional[pulumi.Input[int]] = None,
                 max_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 share_pools: Optional[pulumi.Input[str]] = None,
                 source_mask: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileOneConnectArgs.__new__(ProfileOneConnectArgs)

            __props__.__dict__["defaults_from"] = defaults_from
            __props__.__dict__["idle_timeout_override"] = idle_timeout_override
            __props__.__dict__["limit_type"] = limit_type
            __props__.__dict__["max_age"] = max_age
            __props__.__dict__["max_reuse"] = max_reuse
            __props__.__dict__["max_size"] = max_size
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["partition"] = partition
            __props__.__dict__["share_pools"] = share_pools
            __props__.__dict__["source_mask"] = source_mask
        super(ProfileOneConnect, __self__).__init__(
            'f5bigip:ltm/profileOneConnect:ProfileOneConnect',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            defaults_from: Optional[pulumi.Input[str]] = None,
            idle_timeout_override: Optional[pulumi.Input[str]] = None,
            limit_type: Optional[pulumi.Input[str]] = None,
            max_age: Optional[pulumi.Input[int]] = None,
            max_reuse: Optional[pulumi.Input[int]] = None,
            max_size: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            partition: Optional[pulumi.Input[str]] = None,
            share_pools: Optional[pulumi.Input[str]] = None,
            source_mask: Optional[pulumi.Input[str]] = None) -> 'ProfileOneConnect':
        """
        Get an existing ProfileOneConnect resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] idle_timeout_override: Specifies the number of seconds that a connection is idle before the connection flow is eligible for deletion. Possible values are `disabled`, `indefinite`, or a numeric value that you specify. The default value is `disabled`
        :param pulumi.Input[str] limit_type: Controls how connection limits are enforced in conjunction with OneConnect. The default is `None`. Supported Values: `[None,idle,strict]`
        :param pulumi.Input[int] max_age: Specifies the maximum age in number of seconds allowed for a connection in the connection reuse pool. For any connection with an age higher than this value, the system removes that connection from the reuse pool. The default value is `86400`.
        :param pulumi.Input[int] max_reuse: Specifies the maximum number of times that a server-side connection can be reused. The default value is `1000`.
        :param pulumi.Input[int] max_size: Specifies the maximum number of connections that the system holds in the connection reuse pool. If the pool is already full, then the server-side connection closes after the response is completed. The default value is `10000`.
        :param pulumi.Input[str] name: Name of Profile should be full path.The full path is the combination of the `partition + profile_name`,For example `/Common/test-oneconnect-profile`.
        :param pulumi.Input[str] partition: Displays the administrative partition within which this profile resides
        :param pulumi.Input[str] share_pools: Specify if you want to share the pool, default value is `disabled`.
        :param pulumi.Input[str] source_mask: Specifies a source IP mask. The default value is `0.0.0.0`. The system applies the value of this option to the source address to determine its eligibility for reuse. A mask of 0.0.0.0 causes the system to share reused connections across all clients. A host mask (all 1's in binary), causes the system to share only those reused connections originating from the same client IP address.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileOneConnectState.__new__(_ProfileOneConnectState)

        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["idle_timeout_override"] = idle_timeout_override
        __props__.__dict__["limit_type"] = limit_type
        __props__.__dict__["max_age"] = max_age
        __props__.__dict__["max_reuse"] = max_reuse
        __props__.__dict__["max_size"] = max_size
        __props__.__dict__["name"] = name
        __props__.__dict__["partition"] = partition
        __props__.__dict__["share_pools"] = share_pools
        __props__.__dict__["source_mask"] = source_mask
        return ProfileOneConnect(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[str]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @property
    @pulumi.getter(name="idleTimeoutOverride")
    def idle_timeout_override(self) -> pulumi.Output[str]:
        """
        Specifies the number of seconds that a connection is idle before the connection flow is eligible for deletion. Possible values are `disabled`, `indefinite`, or a numeric value that you specify. The default value is `disabled`
        """
        return pulumi.get(self, "idle_timeout_override")

    @property
    @pulumi.getter(name="limitType")
    def limit_type(self) -> pulumi.Output[str]:
        """
        Controls how connection limits are enforced in conjunction with OneConnect. The default is `None`. Supported Values: `[None,idle,strict]`
        """
        return pulumi.get(self, "limit_type")

    @property
    @pulumi.getter(name="maxAge")
    def max_age(self) -> pulumi.Output[int]:
        """
        Specifies the maximum age in number of seconds allowed for a connection in the connection reuse pool. For any connection with an age higher than this value, the system removes that connection from the reuse pool. The default value is `86400`.
        """
        return pulumi.get(self, "max_age")

    @property
    @pulumi.getter(name="maxReuse")
    def max_reuse(self) -> pulumi.Output[int]:
        """
        Specifies the maximum number of times that a server-side connection can be reused. The default value is `1000`.
        """
        return pulumi.get(self, "max_reuse")

    @property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> pulumi.Output[int]:
        """
        Specifies the maximum number of connections that the system holds in the connection reuse pool. If the pool is already full, then the server-side connection closes after the response is completed. The default value is `10000`.
        """
        return pulumi.get(self, "max_size")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of Profile should be full path.The full path is the combination of the `partition + profile_name`,For example `/Common/test-oneconnect-profile`.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def partition(self) -> pulumi.Output[str]:
        """
        Displays the administrative partition within which this profile resides
        """
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter(name="sharePools")
    def share_pools(self) -> pulumi.Output[str]:
        """
        Specify if you want to share the pool, default value is `disabled`.
        """
        return pulumi.get(self, "share_pools")

    @property
    @pulumi.getter(name="sourceMask")
    def source_mask(self) -> pulumi.Output[str]:
        """
        Specifies a source IP mask. The default value is `0.0.0.0`. The system applies the value of this option to the source address to determine its eligibility for reuse. A mask of 0.0.0.0 causes the system to share reused connections across all clients. A host mask (all 1's in binary), causes the system to share only those reused connections originating from the same client IP address.
        """
        return pulumi.get(self, "source_mask")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetAwsServiceDiscoveryResult',
    'AwaitableGetAwsServiceDiscoveryResult',
    'get_aws_service_discovery',
    'get_aws_service_discovery_output',
]

@pulumi.output_type
class GetAwsServiceDiscoveryResult:
    """
    A collection of values returned by getAwsServiceDiscovery.
    """
    def __init__(__self__, address_realm=None, aws_access_key=None, aws_region=None, aws_sd_json=None, aws_secret_access_key=None, credential_update=None, external_id=None, id=None, minimum_monitors=None, port=None, role_arn=None, tag_key=None, tag_value=None, type=None, undetectable_action=None, update_interval=None):
        if address_realm and not isinstance(address_realm, str):
            raise TypeError("Expected argument 'address_realm' to be a str")
        pulumi.set(__self__, "address_realm", address_realm)
        if aws_access_key and not isinstance(aws_access_key, str):
            raise TypeError("Expected argument 'aws_access_key' to be a str")
        pulumi.set(__self__, "aws_access_key", aws_access_key)
        if aws_region and not isinstance(aws_region, str):
            raise TypeError("Expected argument 'aws_region' to be a str")
        pulumi.set(__self__, "aws_region", aws_region)
        if aws_sd_json and not isinstance(aws_sd_json, str):
            raise TypeError("Expected argument 'aws_sd_json' to be a str")
        pulumi.set(__self__, "aws_sd_json", aws_sd_json)
        if aws_secret_access_key and not isinstance(aws_secret_access_key, str):
            raise TypeError("Expected argument 'aws_secret_access_key' to be a str")
        pulumi.set(__self__, "aws_secret_access_key", aws_secret_access_key)
        if credential_update and not isinstance(credential_update, bool):
            raise TypeError("Expected argument 'credential_update' to be a bool")
        pulumi.set(__self__, "credential_update", credential_update)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if minimum_monitors and not isinstance(minimum_monitors, str):
            raise TypeError("Expected argument 'minimum_monitors' to be a str")
        pulumi.set(__self__, "minimum_monitors", minimum_monitors)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if role_arn and not isinstance(role_arn, str):
            raise TypeError("Expected argument 'role_arn' to be a str")
        pulumi.set(__self__, "role_arn", role_arn)
        if tag_key and not isinstance(tag_key, str):
            raise TypeError("Expected argument 'tag_key' to be a str")
        pulumi.set(__self__, "tag_key", tag_key)
        if tag_value and not isinstance(tag_value, str):
            raise TypeError("Expected argument 'tag_value' to be a str")
        pulumi.set(__self__, "tag_value", tag_value)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if undetectable_action and not isinstance(undetectable_action, str):
            raise TypeError("Expected argument 'undetectable_action' to be a str")
        pulumi.set(__self__, "undetectable_action", undetectable_action)
        if update_interval and not isinstance(update_interval, str):
            raise TypeError("Expected argument 'update_interval' to be a str")
        pulumi.set(__self__, "update_interval", update_interval)

    @property
    @pulumi.getter(name="addressRealm")
    def address_realm(self) -> Optional[str]:
        return pulumi.get(self, "address_realm")

    @property
    @pulumi.getter(name="awsAccessKey")
    def aws_access_key(self) -> Optional[str]:
        return pulumi.get(self, "aws_access_key")

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> str:
        return pulumi.get(self, "aws_region")

    @property
    @pulumi.getter(name="awsSdJson")
    def aws_sd_json(self) -> str:
        """
        The JSON for AWS service discovery block.
        """
        return pulumi.get(self, "aws_sd_json")

    @property
    @pulumi.getter(name="awsSecretAccessKey")
    def aws_secret_access_key(self) -> Optional[str]:
        return pulumi.get(self, "aws_secret_access_key")

    @property
    @pulumi.getter(name="credentialUpdate")
    def credential_update(self) -> Optional[bool]:
        return pulumi.get(self, "credential_update")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="minimumMonitors")
    def minimum_monitors(self) -> Optional[str]:
        return pulumi.get(self, "minimum_monitors")

    @property
    @pulumi.getter
    def port(self) -> Optional[int]:
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> str:
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> str:
        return pulumi.get(self, "tag_key")

    @property
    @pulumi.getter(name="tagValue")
    def tag_value(self) -> str:
        return pulumi.get(self, "tag_value")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="undetectableAction")
    def undetectable_action(self) -> Optional[str]:
        return pulumi.get(self, "undetectable_action")

    @property
    @pulumi.getter(name="updateInterval")
    def update_interval(self) -> Optional[str]:
        return pulumi.get(self, "update_interval")


class AwaitableGetAwsServiceDiscoveryResult(GetAwsServiceDiscoveryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAwsServiceDiscoveryResult(
            address_realm=self.address_realm,
            aws_access_key=self.aws_access_key,
            aws_region=self.aws_region,
            aws_sd_json=self.aws_sd_json,
            aws_secret_access_key=self.aws_secret_access_key,
            credential_update=self.credential_update,
            external_id=self.external_id,
            id=self.id,
            minimum_monitors=self.minimum_monitors,
            port=self.port,
            role_arn=self.role_arn,
            tag_key=self.tag_key,
            tag_value=self.tag_value,
            type=self.type,
            undetectable_action=self.undetectable_action,
            update_interval=self.update_interval)


def get_aws_service_discovery(address_realm: Optional[str] = None,
                              aws_access_key: Optional[str] = None,
                              aws_region: Optional[str] = None,
                              aws_secret_access_key: Optional[str] = None,
                              credential_update: Optional[bool] = None,
                              external_id: Optional[str] = None,
                              minimum_monitors: Optional[str] = None,
                              port: Optional[int] = None,
                              role_arn: Optional[str] = None,
                              tag_key: Optional[str] = None,
                              tag_value: Optional[str] = None,
                              type: Optional[str] = None,
                              undetectable_action: Optional[str] = None,
                              update_interval: Optional[str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAwsServiceDiscoveryResult:
    """
    Use this data source (`fast_get_aws_service_discovery`) to get the AWS Service discovery config to be used for `http`/`https` app deployment in FAST.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    t_c2 = f5bigip.fast.get_aws_service_discovery(tag_key="testawstagkey",
        tag_value="testawstagvalue")
    ```


    :param str address_realm: Specifies whether to look for public or private IP addresses,default `private`.
    :param str aws_access_key: Information for discovering AWS nodes that are not in the same region as your BIG-IP (also requires the `aws_secret_access_key` field)
    :param str aws_region: AWS region in which ADC is running,default Empty string.
    :param str aws_secret_access_key: Information for discovering AWS nodes that are not in the same region as your BIG-IP (also requires the `aws_secret_access_key` field)
    :param bool credential_update: Specifies whether you are updating your credentials,default `false`.
    :param str external_id: AWS externalID field.
    :param str minimum_monitors: Member is down when fewer than minimum monitors report it healthy.
    :param int port: Port to be used for AWS service discovery,default `80`.
    :param str role_arn: Assume a role (also requires the `external_id` field)
    :param str tag_key: The tag key associated with the node to add to this pool.
    :param str tag_value: The tag value associated with the node to add to this pool.
    :param str undetectable_action: Action to take when node cannot be detected,default `remove`.
    :param str update_interval: Update interval for service discovery.
    """
    __args__ = dict()
    __args__['addressRealm'] = address_realm
    __args__['awsAccessKey'] = aws_access_key
    __args__['awsRegion'] = aws_region
    __args__['awsSecretAccessKey'] = aws_secret_access_key
    __args__['credentialUpdate'] = credential_update
    __args__['externalId'] = external_id
    __args__['minimumMonitors'] = minimum_monitors
    __args__['port'] = port
    __args__['roleArn'] = role_arn
    __args__['tagKey'] = tag_key
    __args__['tagValue'] = tag_value
    __args__['type'] = type
    __args__['undetectableAction'] = undetectable_action
    __args__['updateInterval'] = update_interval
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:fast/getAwsServiceDiscovery:getAwsServiceDiscovery', __args__, opts=opts, typ=GetAwsServiceDiscoveryResult).value

    return AwaitableGetAwsServiceDiscoveryResult(
        address_realm=pulumi.get(__ret__, 'address_realm'),
        aws_access_key=pulumi.get(__ret__, 'aws_access_key'),
        aws_region=pulumi.get(__ret__, 'aws_region'),
        aws_sd_json=pulumi.get(__ret__, 'aws_sd_json'),
        aws_secret_access_key=pulumi.get(__ret__, 'aws_secret_access_key'),
        credential_update=pulumi.get(__ret__, 'credential_update'),
        external_id=pulumi.get(__ret__, 'external_id'),
        id=pulumi.get(__ret__, 'id'),
        minimum_monitors=pulumi.get(__ret__, 'minimum_monitors'),
        port=pulumi.get(__ret__, 'port'),
        role_arn=pulumi.get(__ret__, 'role_arn'),
        tag_key=pulumi.get(__ret__, 'tag_key'),
        tag_value=pulumi.get(__ret__, 'tag_value'),
        type=pulumi.get(__ret__, 'type'),
        undetectable_action=pulumi.get(__ret__, 'undetectable_action'),
        update_interval=pulumi.get(__ret__, 'update_interval'))


@_utilities.lift_output_func(get_aws_service_discovery)
def get_aws_service_discovery_output(address_realm: Optional[pulumi.Input[Optional[str]]] = None,
                                     aws_access_key: Optional[pulumi.Input[Optional[str]]] = None,
                                     aws_region: Optional[pulumi.Input[Optional[str]]] = None,
                                     aws_secret_access_key: Optional[pulumi.Input[Optional[str]]] = None,
                                     credential_update: Optional[pulumi.Input[Optional[bool]]] = None,
                                     external_id: Optional[pulumi.Input[Optional[str]]] = None,
                                     minimum_monitors: Optional[pulumi.Input[Optional[str]]] = None,
                                     port: Optional[pulumi.Input[Optional[int]]] = None,
                                     role_arn: Optional[pulumi.Input[Optional[str]]] = None,
                                     tag_key: Optional[pulumi.Input[str]] = None,
                                     tag_value: Optional[pulumi.Input[str]] = None,
                                     type: Optional[pulumi.Input[Optional[str]]] = None,
                                     undetectable_action: Optional[pulumi.Input[Optional[str]]] = None,
                                     update_interval: Optional[pulumi.Input[Optional[str]]] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAwsServiceDiscoveryResult]:
    """
    Use this data source (`fast_get_aws_service_discovery`) to get the AWS Service discovery config to be used for `http`/`https` app deployment in FAST.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    t_c2 = f5bigip.fast.get_aws_service_discovery(tag_key="testawstagkey",
        tag_value="testawstagvalue")
    ```


    :param str address_realm: Specifies whether to look for public or private IP addresses,default `private`.
    :param str aws_access_key: Information for discovering AWS nodes that are not in the same region as your BIG-IP (also requires the `aws_secret_access_key` field)
    :param str aws_region: AWS region in which ADC is running,default Empty string.
    :param str aws_secret_access_key: Information for discovering AWS nodes that are not in the same region as your BIG-IP (also requires the `aws_secret_access_key` field)
    :param bool credential_update: Specifies whether you are updating your credentials,default `false`.
    :param str external_id: AWS externalID field.
    :param str minimum_monitors: Member is down when fewer than minimum monitors report it healthy.
    :param int port: Port to be used for AWS service discovery,default `80`.
    :param str role_arn: Assume a role (also requires the `external_id` field)
    :param str tag_key: The tag key associated with the node to add to this pool.
    :param str tag_value: The tag value associated with the node to add to this pool.
    :param str undetectable_action: Action to take when node cannot be detected,default `remove`.
    :param str update_interval: Update interval for service discovery.
    """
    ...
